@@ -166,8 +166,20 @@ def read_command_line():
         default=False,
         help="(experimental) extract word-level timestamps and refine the results based on them",
     )
-    #    parser.add_argument("--prepend_punctuations", type=str, default="\"\'“¿([{-", help="if word_timestamps is True, merge these punctuation symbols with the next word")
-    # parser.add_argument("--append_punctuations", type=str, default="\"\'.。,，!！?？:：”)]}、", help="if word_timestamps is True, merge these punctuation symbols with the previous word"
+
+    parser.add_argument(
+        "--prepend_punctuations",
+        type=str,
+        default="\"'“¿([{-",
+        help="if word_timestamps is True, merge these punctuation symbols with the next word",
+    )
+    parser.add_argument(
+        "--append_punctuations",
+        type=str,
+        default="\"'.。,，!！?？:：”)]}、",
+        help="if word_timestamps is True, merge these punctuation symbols with the previous word",
+    )
+
     parser.add_argument(
         "--device", default="auto", help="device to use for CTranslate2 inference"
     )
@@ -204,7 +216,7 @@ def read_command_line():
 
     # Whisper-ctranslate2 specific parameters
     parser.add_argument(
-        "--print-colors",
+        "--print_colors",
         type=str2bool,
         default=False,
         help="Print the transcribed text using an experimental color coding strategy to highlight words with high or low confidence",
@@ -238,6 +250,7 @@ def main():
     model_directory: str = args.pop("model_directory")
     cache_directory: str = args.pop("model_dir")
     device_index: Union[int, List[int]] = args.pop("device_index")
+    suppress_tokens: str = args.pop("suppress_tokens")
 
     temperature = args.pop("temperature")
     if (increment := args.pop("temperature_increment_on_fallback")) is not None:
@@ -258,6 +271,7 @@ def main():
             )
         language = "en"
 
+    suppress_tokens = [int(t) for t in suppress_tokens.split(",")]
     options = TranscriptionOptions(
         beam_size=args.pop("beam_size"),
         best_of=args.pop("best_of"),
@@ -271,15 +285,20 @@ def main():
         initial_prompt=args.pop("initial_prompt"),
         #        prefix = None,
         #        suppress_blank = None,
-        suppress_tokens=args.pop("suppress_tokens"),
+        suppress_tokens=suppress_tokens,
         #        without_timestamps = None,
         #        max_initial_timestamp =  None,
         word_timestamps=args.pop("word_timestamps"),
-        #        prepend_punctuations = None,
-        #        append_punctuations = None
+        prepend_punctuations=args.pop("prepend_punctuations"),
+        append_punctuations=args.pop("append_punctuations"),
         print_colors=args.pop("print_colors"),
     )
 
+    if verbose and not language:
+        print(
+            "Detecting language using up to the first 30 seconds. Use `--language` to specify the language"
+        )
+
     if model_directory:
         model_filename = os.path.join(model_directory, "model.bin")
         if not os.path.exists(model_filename):
